package WebService::Braintree::ErrorCodes::Transaction::Options;
$WebService::Braintree::ErrorCodes::Transaction::Options::VERSION = '0.94';
use 5.010_001;
use strictures 1;

use constant SubmitForSettlementIsRequiredForCloning => "91544";
use constant VaultIsDisabled                         => "91525";

1;
__END__
